import logging
import sys


class LoggerAdapter:
    def __init__(self, logger, level=logging.INFO):
        self.logger = logger
        self.level = level

    def write(self, message):
        if message and not message.isspace():
            self.logger.log(self.level, message.rstrip())
        return len(message)

    def flush(self):
        pass

    def fileno(self):
        return sys.stderr.fileno()



from typing import Optional

from uipath._cli._runtime._contracts import UiPathErrorCategory, UiPathRuntimeError


class UiPathMcpRuntimeError(UiPathRuntimeError):
    """Custom exception for MCP runtime errors with structured error information."""

    def __init__(
        self,
        code: str,
        title: str,
        detail: str,
        category: UiPathErrorCategory = UiPathErrorCategory.UNKNOWN,
        status: Optional[int] = None,
    ):
        super().__init__(code, title, detail, category, status, prefix="MCP")



from mcp.server.fastmcp import FastMCP

mcp = FastMCP("Demo")


@mcp.tool()
def add(a: int, b: int) -> int:
    """Add two numbers"""
    return a + b


@mcp.resource("greeting://{name}")
def get_greeting(name: str) -> str:
    """Get a personalized greeting"""
    return f"Hello, {name}!"


if __name__ == "__main__":
    mcp.run()
